/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * An activity resource contains information about an action that a particular channel, or user, has
 * taken on YouTube.The actions reported in activity feeds include rating a video, sharing a video,
 * marking a video as a favorite, commenting on a video, uploading a video, and so forth. Each
 * activity resource identifies the type of action, the channel associated with the action, and the
 * resource(s) associated with the action, such as the video that was rated or uploaded.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Activity extends GenericJson {

  /**
   * The contentDetails object contains information about the content associated with the activity.
   * For example, if the snippet.type value is videoRated, then the contentDetails object's content
   * identifies the rated video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ActivityContentDetails contentDetails;

  /**
   * Etag of this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The ID that YouTube uses to uniquely identify the activity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind, fixed to "youtube#activity".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The snippet object contains basic details about the activity, including the activity's type and
   * group ID.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ActivitySnippet snippet;

  /**
   * The contentDetails object contains information about the content associated with the activity.
   * For example, if the snippet.type value is videoRated, then the contentDetails object's content
   * identifies the rated video.
   * The value returned may be {@code null}.
   */
  public ActivityContentDetails getContentDetails() {
    return contentDetails;
  }

  /**
   * The contentDetails object contains information about the content associated with the activity.
   * For example, if the snippet.type value is videoRated, then the contentDetails object's content
   * identifies the rated video.
   * The value set may be {@code null}.
   */
  public Activity setContentDetails(ActivityContentDetails contentDetails) {
    this.contentDetails = contentDetails;
    return this;
  }

  /**
   * Etag of this resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * Etag of this resource.
   * The value set may be {@code null}.
   */
  public Activity setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The ID that YouTube uses to uniquely identify the activity.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID that YouTube uses to uniquely identify the activity.
   * The value set may be {@code null}.
   */
  public Activity setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind, fixed to "youtube#activity".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind, fixed to "youtube#activity".
   * The value set may be {@code null}.
   */
  public Activity setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The snippet object contains basic details about the activity, including the activity's type and
   * group ID.
   * The value returned may be {@code null}.
   */
  public ActivitySnippet getSnippet() {
    return snippet;
  }

  /**
   * The snippet object contains basic details about the activity, including the activity's type and
   * group ID.
   * The value set may be {@code null}.
   */
  public Activity setSnippet(ActivitySnippet snippet) {
    this.snippet = snippet;
    return this;
  }

}
