/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * Details about the content of a channel.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ChannelContentDetails extends GenericJson {

  /**
   * The googlePlusUserId object identifies the Google+ profile ID associated with this channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String googlePlusUserId;

  /**
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private RelatedPlaylists relatedPlaylists;

  /**
   * The googlePlusUserId object identifies the Google+ profile ID associated with this channel.
   * The value returned may be {@code null}.
   */
  public String getGooglePlusUserId() {
    return googlePlusUserId;
  }

  /**
   * The googlePlusUserId object identifies the Google+ profile ID associated with this channel.
   * The value set may be {@code null}.
   */
  public ChannelContentDetails setGooglePlusUserId(String googlePlusUserId) {
    this.googlePlusUserId = googlePlusUserId;
    return this;
  }

  /**

   * The value returned may be {@code null}.
   */
  public RelatedPlaylists getRelatedPlaylists() {
    return relatedPlaylists;
  }

  /**

   * The value set may be {@code null}.
   */
  public ChannelContentDetails setRelatedPlaylists(RelatedPlaylists relatedPlaylists) {
    this.relatedPlaylists = relatedPlaylists;
    return this;
  }

  /**
   * Model definition for ChannelContentDetailsRelatedPlaylists.
   */
  public static final class RelatedPlaylists extends GenericJson {

    /**
     * The ID of the playlist that contains the channel"s favorite videos. Use the
     * playlistItems.insert and  playlistItems.delete to add or remove items from that list.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String favorites;

    /**
     * The ID of the playlist that contains the channel"s liked videos. Use the   playlistItems.insert
     * and  playlistItems.delete to add or remove items from that list.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String likes;

    /**
     * The ID of the playlist that contains the channel"s uploaded videos. Use the  videos.insert
     * method to upload new videos and the videos.delete method to delete previously uploaded videos.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String uploads;

    /**
     * The ID of the playlist that contains the channel"s watch history. Use the  playlistItems.insert
     * and  playlistItems.delete to add or remove items from that list.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String watchHistory;

    /**
     * The ID of the playlist that contains the channel"s watch later playlist. Use the
     * playlistItems.insert and  playlistItems.delete to add or remove items from that list.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String watchLater;

    /**
     * The ID of the playlist that contains the channel"s favorite videos. Use the
     * playlistItems.insert and  playlistItems.delete to add or remove items from that list.
     * The value returned may be {@code null}.
     */
    public String getFavorites() {
      return favorites;
    }

    /**
     * The ID of the playlist that contains the channel"s favorite videos. Use the
     * playlistItems.insert and  playlistItems.delete to add or remove items from that list.
     * The value set may be {@code null}.
     */
    public RelatedPlaylists setFavorites(String favorites) {
      this.favorites = favorites;
      return this;
    }

    /**
     * The ID of the playlist that contains the channel"s liked videos. Use the   playlistItems.insert
     * and  playlistItems.delete to add or remove items from that list.
     * The value returned may be {@code null}.
     */
    public String getLikes() {
      return likes;
    }

    /**
     * The ID of the playlist that contains the channel"s liked videos. Use the   playlistItems.insert
     * and  playlistItems.delete to add or remove items from that list.
     * The value set may be {@code null}.
     */
    public RelatedPlaylists setLikes(String likes) {
      this.likes = likes;
      return this;
    }

    /**
     * The ID of the playlist that contains the channel"s uploaded videos. Use the  videos.insert
     * method to upload new videos and the videos.delete method to delete previously uploaded videos.
     * The value returned may be {@code null}.
     */
    public String getUploads() {
      return uploads;
    }

    /**
     * The ID of the playlist that contains the channel"s uploaded videos. Use the  videos.insert
     * method to upload new videos and the videos.delete method to delete previously uploaded videos.
     * The value set may be {@code null}.
     */
    public RelatedPlaylists setUploads(String uploads) {
      this.uploads = uploads;
      return this;
    }

    /**
     * The ID of the playlist that contains the channel"s watch history. Use the  playlistItems.insert
     * and  playlistItems.delete to add or remove items from that list.
     * The value returned may be {@code null}.
     */
    public String getWatchHistory() {
      return watchHistory;
    }

    /**
     * The ID of the playlist that contains the channel"s watch history. Use the  playlistItems.insert
     * and  playlistItems.delete to add or remove items from that list.
     * The value set may be {@code null}.
     */
    public RelatedPlaylists setWatchHistory(String watchHistory) {
      this.watchHistory = watchHistory;
      return this;
    }

    /**
     * The ID of the playlist that contains the channel"s watch later playlist. Use the
     * playlistItems.insert and  playlistItems.delete to add or remove items from that list.
     * The value returned may be {@code null}.
     */
    public String getWatchLater() {
      return watchLater;
    }

    /**
     * The ID of the playlist that contains the channel"s watch later playlist. Use the
     * playlistItems.insert and  playlistItems.delete to add or remove items from that list.
     * The value set may be {@code null}.
     */
    public RelatedPlaylists setWatchLater(String watchLater) {
      this.watchLater = watchLater;
      return this;
    }

  }
}
