/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * Branding properties for the channel view.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ChannelSettings extends GenericJson {

  /**
   * Which content tab users should see when viewing the channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String defaultTab;

  /**
   * Specifies the channel description.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * Title for the featured channels tab.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String featuredChannelsTitle;

  /**
   * The list of featured channels.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> featuredChannelsUrls;

  /**
   * Lists keywords associated with the channel, comma-separated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String keywords;

  /**
   * Whether user-submitted comments left on the channel page need to be approved by the channel
   * owner to be publicly visible.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean moderateComments;

  /**
   * A prominent color that can be rendered on this channel page.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String profileColor;

  /**
   * Whether the tab to browse the videos should be displayed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean showBrowseView;

  /**
   * Whether related channels should be proposed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean showRelatedChannels;

  /**
   * Specifies the channel title.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The ID for a Google Analytics account to track and measure traffic to the channels.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String trackingAnalyticsAccountId;

  /**
   * The trailer of the channel, for users that are not subscribers.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String unsubscribedTrailer;

  /**
   * Which content tab users should see when viewing the channel.
   * The value returned may be {@code null}.
   */
  public String getDefaultTab() {
    return defaultTab;
  }

  /**
   * Which content tab users should see when viewing the channel.
   * The value set may be {@code null}.
   */
  public ChannelSettings setDefaultTab(String defaultTab) {
    this.defaultTab = defaultTab;
    return this;
  }

  /**
   * Specifies the channel description.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * Specifies the channel description.
   * The value set may be {@code null}.
   */
  public ChannelSettings setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * Title for the featured channels tab.
   * The value returned may be {@code null}.
   */
  public String getFeaturedChannelsTitle() {
    return featuredChannelsTitle;
  }

  /**
   * Title for the featured channels tab.
   * The value set may be {@code null}.
   */
  public ChannelSettings setFeaturedChannelsTitle(String featuredChannelsTitle) {
    this.featuredChannelsTitle = featuredChannelsTitle;
    return this;
  }

  /**
   * The list of featured channels.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getFeaturedChannelsUrls() {
    return featuredChannelsUrls;
  }

  /**
   * The list of featured channels.
   * The value set may be {@code null}.
   */
  public ChannelSettings setFeaturedChannelsUrls(java.util.List<String> featuredChannelsUrls) {
    this.featuredChannelsUrls = featuredChannelsUrls;
    return this;
  }

  /**
   * Lists keywords associated with the channel, comma-separated.
   * The value returned may be {@code null}.
   */
  public String getKeywords() {
    return keywords;
  }

  /**
   * Lists keywords associated with the channel, comma-separated.
   * The value set may be {@code null}.
   */
  public ChannelSettings setKeywords(String keywords) {
    this.keywords = keywords;
    return this;
  }

  /**
   * Whether user-submitted comments left on the channel page need to be approved by the channel
   * owner to be publicly visible.
   * The value returned may be {@code null}.
   */
  public Boolean getModerateComments() {
    return moderateComments;
  }

  /**
   * Whether user-submitted comments left on the channel page need to be approved by the channel
   * owner to be publicly visible.
   * The value set may be {@code null}.
   */
  public ChannelSettings setModerateComments(Boolean moderateComments) {
    this.moderateComments = moderateComments;
    return this;
  }

  /**
   * A prominent color that can be rendered on this channel page.
   * The value returned may be {@code null}.
   */
  public String getProfileColor() {
    return profileColor;
  }

  /**
   * A prominent color that can be rendered on this channel page.
   * The value set may be {@code null}.
   */
  public ChannelSettings setProfileColor(String profileColor) {
    this.profileColor = profileColor;
    return this;
  }

  /**
   * Whether the tab to browse the videos should be displayed.
   * The value returned may be {@code null}.
   */
  public Boolean getShowBrowseView() {
    return showBrowseView;
  }

  /**
   * Whether the tab to browse the videos should be displayed.
   * The value set may be {@code null}.
   */
  public ChannelSettings setShowBrowseView(Boolean showBrowseView) {
    this.showBrowseView = showBrowseView;
    return this;
  }

  /**
   * Whether related channels should be proposed.
   * The value returned may be {@code null}.
   */
  public Boolean getShowRelatedChannels() {
    return showRelatedChannels;
  }

  /**
   * Whether related channels should be proposed.
   * The value set may be {@code null}.
   */
  public ChannelSettings setShowRelatedChannels(Boolean showRelatedChannels) {
    this.showRelatedChannels = showRelatedChannels;
    return this;
  }

  /**
   * Specifies the channel title.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * Specifies the channel title.
   * The value set may be {@code null}.
   */
  public ChannelSettings setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * The ID for a Google Analytics account to track and measure traffic to the channels.
   * The value returned may be {@code null}.
   */
  public String getTrackingAnalyticsAccountId() {
    return trackingAnalyticsAccountId;
  }

  /**
   * The ID for a Google Analytics account to track and measure traffic to the channels.
   * The value set may be {@code null}.
   */
  public ChannelSettings setTrackingAnalyticsAccountId(String trackingAnalyticsAccountId) {
    this.trackingAnalyticsAccountId = trackingAnalyticsAccountId;
    return this;
  }

  /**
   * The trailer of the channel, for users that are not subscribers.
   * The value returned may be {@code null}.
   */
  public String getUnsubscribedTrailer() {
    return unsubscribedTrailer;
  }

  /**
   * The trailer of the channel, for users that are not subscribers.
   * The value set may be {@code null}.
   */
  public ChannelSettings setUnsubscribedTrailer(String unsubscribedTrailer) {
    this.unsubscribedTrailer = unsubscribedTrailer;
    return this;
  }

}
