/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * Branding properties for images associated with the channel.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ImageSettings extends GenericJson {

  /**
   * The URL for the background image shown on the video watch page. The image should be 1200px by
   * 615px, with a maximum file size of 128k.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LocalizedProperty backgroundImageUrl;

  /**
   * This is used only in update requests; if it's set, we use this URL to generate all of the above
   * banner URLs.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerExternalUrl;

  /**
   * Banner image. Desktop size (1060x175).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerImageUrl;

  /**
   * Banner image. Mobile size high resolution (1440x395).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerMobileExtraHdImageUrl;

  /**
   * Banner image. Mobile size high resolution (1280x360).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerMobileHdImageUrl;

  /**
   * Banner image. Mobile size (640x175).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerMobileImageUrl;

  /**
   * Banner image. Mobile size low resolution (320x88).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerMobileLowImageUrl;

  /**
   * Banner image. Mobile size medium/high resolution (960x263).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerMobileMediumHdImageUrl;

  /**
   * Banner image. Tablet size extra high resolution (2560x424).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerTabletExtraHdImageUrl;

  /**
   * Banner image. Tablet size high resolution (2276x377).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerTabletHdImageUrl;

  /**
   * Banner image. Tablet size (1707x283).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerTabletImageUrl;

  /**
   * Banner image. Tablet size low resolution (1138x188).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerTabletLowImageUrl;

  /**
   * Banner image. TV size (2120x1192).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bannerTvImageUrl;

  /**
   * The image map script for the large banner image.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LocalizedProperty largeBrandedBannerImageImapScript;

  /**
   * The URL for the 854px by 70px image that appears below the video player in the expanded video
   * view of the video watch page.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LocalizedProperty largeBrandedBannerImageUrl;

  /**
   * The image map script for the small banner image.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LocalizedProperty smallBrandedBannerImageImapScript;

  /**
   * The URL for the 640px by 70px banner image that appears below the video player in the default
   * view of the video watch page.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LocalizedProperty smallBrandedBannerImageUrl;

  /**
   * The URL for a 1px by 1px tracking pixel that can be used to collect statistics for views of the
   * channel or video pages.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String trackingImageUrl;

  /**
   * The URL for the image that appears above the top-left corner of the video player. This is a 25
   * -pixel-high image with a flexible width that cannot exceed 170 pixels.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String watchIconImageUrl;

  /**
   * The URL for the background image shown on the video watch page. The image should be 1200px by
   * 615px, with a maximum file size of 128k.
   * The value returned may be {@code null}.
   */
  public LocalizedProperty getBackgroundImageUrl() {
    return backgroundImageUrl;
  }

  /**
   * The URL for the background image shown on the video watch page. The image should be 1200px by
   * 615px, with a maximum file size of 128k.
   * The value set may be {@code null}.
   */
  public ImageSettings setBackgroundImageUrl(LocalizedProperty backgroundImageUrl) {
    this.backgroundImageUrl = backgroundImageUrl;
    return this;
  }

  /**
   * This is used only in update requests; if it's set, we use this URL to generate all of the above
   * banner URLs.
   * The value returned may be {@code null}.
   */
  public String getBannerExternalUrl() {
    return bannerExternalUrl;
  }

  /**
   * This is used only in update requests; if it's set, we use this URL to generate all of the above
   * banner URLs.
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerExternalUrl(String bannerExternalUrl) {
    this.bannerExternalUrl = bannerExternalUrl;
    return this;
  }

  /**
   * Banner image. Desktop size (1060x175).
   * The value returned may be {@code null}.
   */
  public String getBannerImageUrl() {
    return bannerImageUrl;
  }

  /**
   * Banner image. Desktop size (1060x175).
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerImageUrl(String bannerImageUrl) {
    this.bannerImageUrl = bannerImageUrl;
    return this;
  }

  /**
   * Banner image. Mobile size high resolution (1440x395).
   * The value returned may be {@code null}.
   */
  public String getBannerMobileExtraHdImageUrl() {
    return bannerMobileExtraHdImageUrl;
  }

  /**
   * Banner image. Mobile size high resolution (1440x395).
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerMobileExtraHdImageUrl(String bannerMobileExtraHdImageUrl) {
    this.bannerMobileExtraHdImageUrl = bannerMobileExtraHdImageUrl;
    return this;
  }

  /**
   * Banner image. Mobile size high resolution (1280x360).
   * The value returned may be {@code null}.
   */
  public String getBannerMobileHdImageUrl() {
    return bannerMobileHdImageUrl;
  }

  /**
   * Banner image. Mobile size high resolution (1280x360).
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerMobileHdImageUrl(String bannerMobileHdImageUrl) {
    this.bannerMobileHdImageUrl = bannerMobileHdImageUrl;
    return this;
  }

  /**
   * Banner image. Mobile size (640x175).
   * The value returned may be {@code null}.
   */
  public String getBannerMobileImageUrl() {
    return bannerMobileImageUrl;
  }

  /**
   * Banner image. Mobile size (640x175).
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerMobileImageUrl(String bannerMobileImageUrl) {
    this.bannerMobileImageUrl = bannerMobileImageUrl;
    return this;
  }

  /**
   * Banner image. Mobile size low resolution (320x88).
   * The value returned may be {@code null}.
   */
  public String getBannerMobileLowImageUrl() {
    return bannerMobileLowImageUrl;
  }

  /**
   * Banner image. Mobile size low resolution (320x88).
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerMobileLowImageUrl(String bannerMobileLowImageUrl) {
    this.bannerMobileLowImageUrl = bannerMobileLowImageUrl;
    return this;
  }

  /**
   * Banner image. Mobile size medium/high resolution (960x263).
   * The value returned may be {@code null}.
   */
  public String getBannerMobileMediumHdImageUrl() {
    return bannerMobileMediumHdImageUrl;
  }

  /**
   * Banner image. Mobile size medium/high resolution (960x263).
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerMobileMediumHdImageUrl(String bannerMobileMediumHdImageUrl) {
    this.bannerMobileMediumHdImageUrl = bannerMobileMediumHdImageUrl;
    return this;
  }

  /**
   * Banner image. Tablet size extra high resolution (2560x424).
   * The value returned may be {@code null}.
   */
  public String getBannerTabletExtraHdImageUrl() {
    return bannerTabletExtraHdImageUrl;
  }

  /**
   * Banner image. Tablet size extra high resolution (2560x424).
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerTabletExtraHdImageUrl(String bannerTabletExtraHdImageUrl) {
    this.bannerTabletExtraHdImageUrl = bannerTabletExtraHdImageUrl;
    return this;
  }

  /**
   * Banner image. Tablet size high resolution (2276x377).
   * The value returned may be {@code null}.
   */
  public String getBannerTabletHdImageUrl() {
    return bannerTabletHdImageUrl;
  }

  /**
   * Banner image. Tablet size high resolution (2276x377).
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerTabletHdImageUrl(String bannerTabletHdImageUrl) {
    this.bannerTabletHdImageUrl = bannerTabletHdImageUrl;
    return this;
  }

  /**
   * Banner image. Tablet size (1707x283).
   * The value returned may be {@code null}.
   */
  public String getBannerTabletImageUrl() {
    return bannerTabletImageUrl;
  }

  /**
   * Banner image. Tablet size (1707x283).
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerTabletImageUrl(String bannerTabletImageUrl) {
    this.bannerTabletImageUrl = bannerTabletImageUrl;
    return this;
  }

  /**
   * Banner image. Tablet size low resolution (1138x188).
   * The value returned may be {@code null}.
   */
  public String getBannerTabletLowImageUrl() {
    return bannerTabletLowImageUrl;
  }

  /**
   * Banner image. Tablet size low resolution (1138x188).
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerTabletLowImageUrl(String bannerTabletLowImageUrl) {
    this.bannerTabletLowImageUrl = bannerTabletLowImageUrl;
    return this;
  }

  /**
   * Banner image. TV size (2120x1192).
   * The value returned may be {@code null}.
   */
  public String getBannerTvImageUrl() {
    return bannerTvImageUrl;
  }

  /**
   * Banner image. TV size (2120x1192).
   * The value set may be {@code null}.
   */
  public ImageSettings setBannerTvImageUrl(String bannerTvImageUrl) {
    this.bannerTvImageUrl = bannerTvImageUrl;
    return this;
  }

  /**
   * The image map script for the large banner image.
   * The value returned may be {@code null}.
   */
  public LocalizedProperty getLargeBrandedBannerImageImapScript() {
    return largeBrandedBannerImageImapScript;
  }

  /**
   * The image map script for the large banner image.
   * The value set may be {@code null}.
   */
  public ImageSettings setLargeBrandedBannerImageImapScript(LocalizedProperty largeBrandedBannerImageImapScript) {
    this.largeBrandedBannerImageImapScript = largeBrandedBannerImageImapScript;
    return this;
  }

  /**
   * The URL for the 854px by 70px image that appears below the video player in the expanded video
   * view of the video watch page.
   * The value returned may be {@code null}.
   */
  public LocalizedProperty getLargeBrandedBannerImageUrl() {
    return largeBrandedBannerImageUrl;
  }

  /**
   * The URL for the 854px by 70px image that appears below the video player in the expanded video
   * view of the video watch page.
   * The value set may be {@code null}.
   */
  public ImageSettings setLargeBrandedBannerImageUrl(LocalizedProperty largeBrandedBannerImageUrl) {
    this.largeBrandedBannerImageUrl = largeBrandedBannerImageUrl;
    return this;
  }

  /**
   * The image map script for the small banner image.
   * The value returned may be {@code null}.
   */
  public LocalizedProperty getSmallBrandedBannerImageImapScript() {
    return smallBrandedBannerImageImapScript;
  }

  /**
   * The image map script for the small banner image.
   * The value set may be {@code null}.
   */
  public ImageSettings setSmallBrandedBannerImageImapScript(LocalizedProperty smallBrandedBannerImageImapScript) {
    this.smallBrandedBannerImageImapScript = smallBrandedBannerImageImapScript;
    return this;
  }

  /**
   * The URL for the 640px by 70px banner image that appears below the video player in the default
   * view of the video watch page.
   * The value returned may be {@code null}.
   */
  public LocalizedProperty getSmallBrandedBannerImageUrl() {
    return smallBrandedBannerImageUrl;
  }

  /**
   * The URL for the 640px by 70px banner image that appears below the video player in the default
   * view of the video watch page.
   * The value set may be {@code null}.
   */
  public ImageSettings setSmallBrandedBannerImageUrl(LocalizedProperty smallBrandedBannerImageUrl) {
    this.smallBrandedBannerImageUrl = smallBrandedBannerImageUrl;
    return this;
  }

  /**
   * The URL for a 1px by 1px tracking pixel that can be used to collect statistics for views of the
   * channel or video pages.
   * The value returned may be {@code null}.
   */
  public String getTrackingImageUrl() {
    return trackingImageUrl;
  }

  /**
   * The URL for a 1px by 1px tracking pixel that can be used to collect statistics for views of the
   * channel or video pages.
   * The value set may be {@code null}.
   */
  public ImageSettings setTrackingImageUrl(String trackingImageUrl) {
    this.trackingImageUrl = trackingImageUrl;
    return this;
  }

  /**
   * The URL for the image that appears above the top-left corner of the video player. This is a 25
   * -pixel-high image with a flexible width that cannot exceed 170 pixels.
   * The value returned may be {@code null}.
   */
  public String getWatchIconImageUrl() {
    return watchIconImageUrl;
  }

  /**
   * The URL for the image that appears above the top-left corner of the video player. This is a 25
   * -pixel-high image with a flexible width that cannot exceed 170 pixels.
   * The value set may be {@code null}.
   */
  public ImageSettings setWatchIconImageUrl(String watchIconImageUrl) {
    this.watchIconImageUrl = watchIconImageUrl;
    return this;
  }

}
