/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * A live stream describes a live ingestion point.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class LiveStream extends GenericJson {

  /**
   * The cdn object defines the live stream's content delivery network (CDN) settings. These
   * settings provide details about the manner in which you stream your content to YouTube.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private CdnSettings cdn;

  /**
   * The content_details object contains information about the stream, including the closed captions
   * ingestion URL.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LiveStreamContentDetails contentDetails;

  /**
   * Etag of this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The ID that YouTube assigns to uniquely identify the stream.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind, fixed to "youtube#liveStream".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The snippet object contains basic details about the stream, including its channel, title, and
   * description.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LiveStreamSnippet snippet;

  /**
   * The status object contains information about live stream's status.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LiveStreamStatus status;

  /**
   * The cdn object defines the live stream's content delivery network (CDN) settings. These
   * settings provide details about the manner in which you stream your content to YouTube.
   * The value returned may be {@code null}.
   */
  public CdnSettings getCdn() {
    return cdn;
  }

  /**
   * The cdn object defines the live stream's content delivery network (CDN) settings. These
   * settings provide details about the manner in which you stream your content to YouTube.
   * The value set may be {@code null}.
   */
  public LiveStream setCdn(CdnSettings cdn) {
    this.cdn = cdn;
    return this;
  }

  /**
   * The content_details object contains information about the stream, including the closed captions
   * ingestion URL.
   * The value returned may be {@code null}.
   */
  public LiveStreamContentDetails getContentDetails() {
    return contentDetails;
  }

  /**
   * The content_details object contains information about the stream, including the closed captions
   * ingestion URL.
   * The value set may be {@code null}.
   */
  public LiveStream setContentDetails(LiveStreamContentDetails contentDetails) {
    this.contentDetails = contentDetails;
    return this;
  }

  /**
   * Etag of this resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * Etag of this resource.
   * The value set may be {@code null}.
   */
  public LiveStream setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The ID that YouTube assigns to uniquely identify the stream.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID that YouTube assigns to uniquely identify the stream.
   * The value set may be {@code null}.
   */
  public LiveStream setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind, fixed to "youtube#liveStream".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind, fixed to "youtube#liveStream".
   * The value set may be {@code null}.
   */
  public LiveStream setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The snippet object contains basic details about the stream, including its channel, title, and
   * description.
   * The value returned may be {@code null}.
   */
  public LiveStreamSnippet getSnippet() {
    return snippet;
  }

  /**
   * The snippet object contains basic details about the stream, including its channel, title, and
   * description.
   * The value set may be {@code null}.
   */
  public LiveStream setSnippet(LiveStreamSnippet snippet) {
    this.snippet = snippet;
    return this;
  }

  /**
   * The status object contains information about live stream's status.
   * The value returned may be {@code null}.
   */
  public LiveStreamStatus getStatus() {
    return status;
  }

  /**
   * The status object contains information about live stream's status.
   * The value set may be {@code null}.
   */
  public LiveStream setStatus(LiveStreamStatus status) {
    this.status = status;
    return this;
  }

}
