/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * A playlistItem resource identifies another resource, such as a video, that is included in a
 * playlist. In addition, the playlistItem  resource contains details about the included resource
 * that pertain specifically to how that resource is used in that playlist.
 *
 * YouTube uses playlists to identify special collections of videos for a channel, such as:   -
 * uploaded videos  - favorite videos  - positively rated (liked) videos  - watch history  - watch
 * later  To be more specific, these lists are associated with a channel, which is a collection of a
 * person, group, or company's videos, playlists, and other YouTube information.
 *
 * You can retrieve the playlist IDs for each of these lists from the  channel resource  for a given
 * channel. You can then use the   playlistItems.list method to retrieve any of those lists. You can
 * also add or remove items from those lists by calling the   playlistItems.insert and
 * playlistItems.delete methods. For example, if a user gives a positive rating to a video, you
 * would insert that video into the liked videos playlist for that user's channel.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class PlaylistItem extends GenericJson {

  /**
   * The contentDetails object is included in the resource if the included item is a YouTube video.
   * The object contains additional information about the video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PlaylistItemContentDetails contentDetails;

  /**
   * Etag of this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The ID that YouTube uses to uniquely identify the playlist item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind, fixed to "youtube#playlistItem".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The snippet object contains basic details about the playlist item, such as its title and
   * position in the playlist.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PlaylistItemSnippet snippet;

  /**
   * The status object contains information about the playlist item's privacy status.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PlaylistItemStatus status;

  /**
   * The contentDetails object is included in the resource if the included item is a YouTube video.
   * The object contains additional information about the video.
   * The value returned may be {@code null}.
   */
  public PlaylistItemContentDetails getContentDetails() {
    return contentDetails;
  }

  /**
   * The contentDetails object is included in the resource if the included item is a YouTube video.
   * The object contains additional information about the video.
   * The value set may be {@code null}.
   */
  public PlaylistItem setContentDetails(PlaylistItemContentDetails contentDetails) {
    this.contentDetails = contentDetails;
    return this;
  }

  /**
   * Etag of this resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * Etag of this resource.
   * The value set may be {@code null}.
   */
  public PlaylistItem setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The ID that YouTube uses to uniquely identify the playlist item.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID that YouTube uses to uniquely identify the playlist item.
   * The value set may be {@code null}.
   */
  public PlaylistItem setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind, fixed to "youtube#playlistItem".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind, fixed to "youtube#playlistItem".
   * The value set may be {@code null}.
   */
  public PlaylistItem setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The snippet object contains basic details about the playlist item, such as its title and
   * position in the playlist.
   * The value returned may be {@code null}.
   */
  public PlaylistItemSnippet getSnippet() {
    return snippet;
  }

  /**
   * The snippet object contains basic details about the playlist item, such as its title and
   * position in the playlist.
   * The value set may be {@code null}.
   */
  public PlaylistItem setSnippet(PlaylistItemSnippet snippet) {
    this.snippet = snippet;
    return this;
  }

  /**
   * The status object contains information about the playlist item's privacy status.
   * The value returned may be {@code null}.
   */
  public PlaylistItemStatus getStatus() {
    return status;
  }

  /**
   * The status object contains information about the playlist item's privacy status.
   * The value set may be {@code null}.
   */
  public PlaylistItem setStatus(PlaylistItemStatus status) {
    this.status = status;
    return this;
  }

}
