/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Basic details about a playlist, including title, description and thumbnails.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class PlaylistItemSnippet extends GenericJson {

  /**
   * The ID that YouTube uses to uniquely identify the user that added the item to the playlist.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String channelId;

  /**
   * Channel title for the channel that the playlist item belongs to.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String channelTitle;

  /**
   * The item's description.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The ID that YouTube uses to uniquely identify the playlist that the playlist item is in.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String playlistId;

  /**
   * The order in which the item appears in the playlist. The value uses a zero-based index, so the
   * first item has a position of 0, the second item has a position of 1, and so forth.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Long position;

  /**
   * The date and time that the item was added to the playlist. The value is specified in ISO 8601
   * (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime publishedAt;

  /**
   * The id object contains information that can be used to uniquely identify the resource that is
   * included in the playlist as the playlist item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ResourceId resourceId;

  /**
   * A map of thumbnail images associated with the playlist item. For each object in the map, the
   * key is the name of the thumbnail image, and the value is an object that contains other
   * information about the thumbnail.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ThumbnailDetails thumbnails;

  /**
   * The item's title.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The ID that YouTube uses to uniquely identify the user that added the item to the playlist.
   * The value returned may be {@code null}.
   */
  public String getChannelId() {
    return channelId;
  }

  /**
   * The ID that YouTube uses to uniquely identify the user that added the item to the playlist.
   * The value set may be {@code null}.
   */
  public PlaylistItemSnippet setChannelId(String channelId) {
    this.channelId = channelId;
    return this;
  }

  /**
   * Channel title for the channel that the playlist item belongs to.
   * The value returned may be {@code null}.
   */
  public String getChannelTitle() {
    return channelTitle;
  }

  /**
   * Channel title for the channel that the playlist item belongs to.
   * The value set may be {@code null}.
   */
  public PlaylistItemSnippet setChannelTitle(String channelTitle) {
    this.channelTitle = channelTitle;
    return this;
  }

  /**
   * The item's description.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * The item's description.
   * The value set may be {@code null}.
   */
  public PlaylistItemSnippet setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The ID that YouTube uses to uniquely identify the playlist that the playlist item is in.
   * The value returned may be {@code null}.
   */
  public String getPlaylistId() {
    return playlistId;
  }

  /**
   * The ID that YouTube uses to uniquely identify the playlist that the playlist item is in.
   * The value set may be {@code null}.
   */
  public PlaylistItemSnippet setPlaylistId(String playlistId) {
    this.playlistId = playlistId;
    return this;
  }

  /**
   * The order in which the item appears in the playlist. The value uses a zero-based index, so the
   * first item has a position of 0, the second item has a position of 1, and so forth.
   * The value returned may be {@code null}.
   */
  public Long getPosition() {
    return position;
  }

  /**
   * The order in which the item appears in the playlist. The value uses a zero-based index, so the
   * first item has a position of 0, the second item has a position of 1, and so forth.
   * The value set may be {@code null}.
   */
  public PlaylistItemSnippet setPosition(Long position) {
    this.position = position;
    return this;
  }

  /**
   * The date and time that the item was added to the playlist. The value is specified in ISO 8601
   * (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value returned may be {@code null}.
   */
  public DateTime getPublishedAt() {
    return publishedAt;
  }

  /**
   * The date and time that the item was added to the playlist. The value is specified in ISO 8601
   * (YYYY-MM-DDThh:mm:ss.sZ) format.
   * The value set may be {@code null}.
   */
  public PlaylistItemSnippet setPublishedAt(DateTime publishedAt) {
    this.publishedAt = publishedAt;
    return this;
  }

  /**
   * The id object contains information that can be used to uniquely identify the resource that is
   * included in the playlist as the playlist item.
   * The value returned may be {@code null}.
   */
  public ResourceId getResourceId() {
    return resourceId;
  }

  /**
   * The id object contains information that can be used to uniquely identify the resource that is
   * included in the playlist as the playlist item.
   * The value set may be {@code null}.
   */
  public PlaylistItemSnippet setResourceId(ResourceId resourceId) {
    this.resourceId = resourceId;
    return this;
  }

  /**
   * A map of thumbnail images associated with the playlist item. For each object in the map, the
   * key is the name of the thumbnail image, and the value is an object that contains other
   * information about the thumbnail.
   * The value returned may be {@code null}.
   */
  public ThumbnailDetails getThumbnails() {
    return thumbnails;
  }

  /**
   * A map of thumbnail images associated with the playlist item. For each object in the map, the
   * key is the name of the thumbnail image, and the value is an object that contains other
   * information about the thumbnail.
   * The value set may be {@code null}.
   */
  public PlaylistItemSnippet setThumbnails(ThumbnailDetails thumbnails) {
    this.thumbnails = thumbnails;
    return this;
  }

  /**
   * The item's title.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The item's title.
   * The value set may be {@code null}.
   */
  public PlaylistItemSnippet setTitle(String title) {
    this.title = title;
    return this;
  }

}
