/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * A resource id is a generic reference that points to another YouTube resource.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ResourceId extends GenericJson {

  /**
   * The ID that YouTube uses to uniquely identify the referred resource, if that resource is a
   * channel. This property is only present if the resourceId.kind value is youtube#channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String channelId;

  /**
   * The type of the API resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The ID that YouTube uses to uniquely identify the referred resource, if that resource is a
   * playlist. This property is only present if the resourceId.kind value is youtube#playlist.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String playlistId;

  /**
   * The ID that YouTube uses to uniquely identify the referred resource, if that resource is a
   * video. This property is only present if the resourceId.kind value is youtube#video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String videoId;

  /**
   * The ID that YouTube uses to uniquely identify the referred resource, if that resource is a
   * channel. This property is only present if the resourceId.kind value is youtube#channel.
   * The value returned may be {@code null}.
   */
  public String getChannelId() {
    return channelId;
  }

  /**
   * The ID that YouTube uses to uniquely identify the referred resource, if that resource is a
   * channel. This property is only present if the resourceId.kind value is youtube#channel.
   * The value set may be {@code null}.
   */
  public ResourceId setChannelId(String channelId) {
    this.channelId = channelId;
    return this;
  }

  /**
   * The type of the API resource.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The type of the API resource.
   * The value set may be {@code null}.
   */
  public ResourceId setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The ID that YouTube uses to uniquely identify the referred resource, if that resource is a
   * playlist. This property is only present if the resourceId.kind value is youtube#playlist.
   * The value returned may be {@code null}.
   */
  public String getPlaylistId() {
    return playlistId;
  }

  /**
   * The ID that YouTube uses to uniquely identify the referred resource, if that resource is a
   * playlist. This property is only present if the resourceId.kind value is youtube#playlist.
   * The value set may be {@code null}.
   */
  public ResourceId setPlaylistId(String playlistId) {
    this.playlistId = playlistId;
    return this;
  }

  /**
   * The ID that YouTube uses to uniquely identify the referred resource, if that resource is a
   * video. This property is only present if the resourceId.kind value is youtube#video.
   * The value returned may be {@code null}.
   */
  public String getVideoId() {
    return videoId;
  }

  /**
   * The ID that YouTube uses to uniquely identify the referred resource, if that resource is a
   * video. This property is only present if the resourceId.kind value is youtube#video.
   * The value set may be {@code null}.
   */
  public ResourceId setVideoId(String videoId) {
    this.videoId = videoId;
    return this;
  }

}
