/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * A paginated list of search results returned as the response to a youtube.search.list call.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class SearchListResponse extends GenericJson {

  /**
   * The ETag for the response.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * Serialized EventId of the request which produced this response.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String eventId;

  /**
   * A list of results that match the search criteria.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<SearchResult> items;

  static {
    // hack to force ProGuard to consider SearchResult used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(SearchResult.class);
  }

  /**
   * The type of the API response. For this operation, the value will be youtube#searchListResponse.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The token that can be used as the value of the pageToken parameter to retrieve the next page in
   * the result set.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String nextPageToken;

  /**
   * The pageInfo object encapsulates paging information for the search result set.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PageInfo pageInfo;

  /**
   * The token that can be used as the value of the pageToken parameter to retrieve the previous
   * page in the result set.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String prevPageToken;

  /**
   * The visitorId identifies the visitor.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String visitorId;

  /**
   * The ETag for the response.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * The ETag for the response.
   * The value set may be {@code null}.
   */
  public SearchListResponse setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * Serialized EventId of the request which produced this response.
   * The value returned may be {@code null}.
   */
  public String getEventId() {
    return eventId;
  }

  /**
   * Serialized EventId of the request which produced this response.
   * The value set may be {@code null}.
   */
  public SearchListResponse setEventId(String eventId) {
    this.eventId = eventId;
    return this;
  }

  /**
   * A list of results that match the search criteria.
   * The value returned may be {@code null}.
   */
  public java.util.List<SearchResult> getItems() {
    return items;
  }

  /**
   * A list of results that match the search criteria.
   * The value set may be {@code null}.
   */
  public SearchListResponse setItems(java.util.List<SearchResult> items) {
    this.items = items;
    return this;
  }

  /**
   * The type of the API response. For this operation, the value will be youtube#searchListResponse.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The type of the API response. For this operation, the value will be youtube#searchListResponse.
   * The value set may be {@code null}.
   */
  public SearchListResponse setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The token that can be used as the value of the pageToken parameter to retrieve the next page in
   * the result set.
   * The value returned may be {@code null}.
   */
  public String getNextPageToken() {
    return nextPageToken;
  }

  /**
   * The token that can be used as the value of the pageToken parameter to retrieve the next page in
   * the result set.
   * The value set may be {@code null}.
   */
  public SearchListResponse setNextPageToken(String nextPageToken) {
    this.nextPageToken = nextPageToken;
    return this;
  }

  /**
   * The pageInfo object encapsulates paging information for the search result set.
   * The value returned may be {@code null}.
   */
  public PageInfo getPageInfo() {
    return pageInfo;
  }

  /**
   * The pageInfo object encapsulates paging information for the search result set.
   * The value set may be {@code null}.
   */
  public SearchListResponse setPageInfo(PageInfo pageInfo) {
    this.pageInfo = pageInfo;
    return this;
  }

  /**
   * The token that can be used as the value of the pageToken parameter to retrieve the previous
   * page in the result set.
   * The value returned may be {@code null}.
   */
  public String getPrevPageToken() {
    return prevPageToken;
  }

  /**
   * The token that can be used as the value of the pageToken parameter to retrieve the previous
   * page in the result set.
   * The value set may be {@code null}.
   */
  public SearchListResponse setPrevPageToken(String prevPageToken) {
    this.prevPageToken = prevPageToken;
    return this;
  }

  /**
   * The visitorId identifies the visitor.
   * The value returned may be {@code null}.
   */
  public String getVisitorId() {
    return visitorId;
  }

  /**
   * The visitorId identifies the visitor.
   * The value set may be {@code null}.
   */
  public SearchListResponse setVisitorId(String visitorId) {
    this.visitorId = visitorId;
    return this;
  }

}
