/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * A search result contains information about a YouTube video, channel, or playlist that matches the
 * search parameters specified in an API request. While a search result points to a uniquely
 * identifiable resource, like a video, it does not have its own persistent data.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class SearchResult extends GenericJson {

  /**
   * Etag of this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The id object contains information that can be used to uniquely identify the resource that
   * matches the search request.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ResourceId id;

  /**
   * The kind, fixed to "youtube#searchResult".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The snippet object contains basic details about a search result, such as its title or
   * description. For example, if the search result is a video, then the title will be the video's
   * title and the description will be the video's description.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SearchResultSnippet snippet;

  /**
   * Etag of this resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * Etag of this resource.
   * The value set may be {@code null}.
   */
  public SearchResult setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The id object contains information that can be used to uniquely identify the resource that
   * matches the search request.
   * The value returned may be {@code null}.
   */
  public ResourceId getId() {
    return id;
  }

  /**
   * The id object contains information that can be used to uniquely identify the resource that
   * matches the search request.
   * The value set may be {@code null}.
   */
  public SearchResult setId(ResourceId id) {
    this.id = id;
    return this;
  }

  /**
   * The kind, fixed to "youtube#searchResult".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind, fixed to "youtube#searchResult".
   * The value set may be {@code null}.
   */
  public SearchResult setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The snippet object contains basic details about a search result, such as its title or
   * description. For example, if the search result is a video, then the title will be the video's
   * title and the description will be the video's description.
   * The value returned may be {@code null}.
   */
  public SearchResultSnippet getSnippet() {
    return snippet;
  }

  /**
   * The snippet object contains basic details about a search result, such as its title or
   * description. For example, if the search result is a video, then the title will be the video's
   * title and the description will be the video's description.
   * The value set may be {@code null}.
   */
  public SearchResult setSnippet(SearchResultSnippet snippet) {
    this.snippet = snippet;
    return this;
  }

}
