/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Basic details about a subscription, including title, description and thumbnails of the subscribed
 * item.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class SubscriptionSnippet extends GenericJson {

  /**
   * The ID that YouTube uses to uniquely identify the subscriber's channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String channelId;

  /**
   * Channel title for the channel that the subscription belongs to.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String channelTitle;

  /**
   * The subscription's details.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The date and time that the subscription was created. The value is specified in ISO 8601 (YYYY-
   * MM-DDThh:mm:ss.sZ) format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime publishedAt;

  /**
   * The id object contains information about the channel that the user subscribed to.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ResourceId resourceId;

  /**
   * A map of thumbnail images associated with the video. For each object in the map, the key is the
   * name of the thumbnail image, and the value is an object that contains other information about
   * the thumbnail.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ThumbnailDetails thumbnails;

  /**
   * The subscription's title.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The ID that YouTube uses to uniquely identify the subscriber's channel.
   * The value returned may be {@code null}.
   */
  public String getChannelId() {
    return channelId;
  }

  /**
   * The ID that YouTube uses to uniquely identify the subscriber's channel.
   * The value set may be {@code null}.
   */
  public SubscriptionSnippet setChannelId(String channelId) {
    this.channelId = channelId;
    return this;
  }

  /**
   * Channel title for the channel that the subscription belongs to.
   * The value returned may be {@code null}.
   */
  public String getChannelTitle() {
    return channelTitle;
  }

  /**
   * Channel title for the channel that the subscription belongs to.
   * The value set may be {@code null}.
   */
  public SubscriptionSnippet setChannelTitle(String channelTitle) {
    this.channelTitle = channelTitle;
    return this;
  }

  /**
   * The subscription's details.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * The subscription's details.
   * The value set may be {@code null}.
   */
  public SubscriptionSnippet setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The date and time that the subscription was created. The value is specified in ISO 8601 (YYYY-
   * MM-DDThh:mm:ss.sZ) format.
   * The value returned may be {@code null}.
   */
  public DateTime getPublishedAt() {
    return publishedAt;
  }

  /**
   * The date and time that the subscription was created. The value is specified in ISO 8601 (YYYY-
   * MM-DDThh:mm:ss.sZ) format.
   * The value set may be {@code null}.
   */
  public SubscriptionSnippet setPublishedAt(DateTime publishedAt) {
    this.publishedAt = publishedAt;
    return this;
  }

  /**
   * The id object contains information about the channel that the user subscribed to.
   * The value returned may be {@code null}.
   */
  public ResourceId getResourceId() {
    return resourceId;
  }

  /**
   * The id object contains information about the channel that the user subscribed to.
   * The value set may be {@code null}.
   */
  public SubscriptionSnippet setResourceId(ResourceId resourceId) {
    this.resourceId = resourceId;
    return this;
  }

  /**
   * A map of thumbnail images associated with the video. For each object in the map, the key is the
   * name of the thumbnail image, and the value is an object that contains other information about
   * the thumbnail.
   * The value returned may be {@code null}.
   */
  public ThumbnailDetails getThumbnails() {
    return thumbnails;
  }

  /**
   * A map of thumbnail images associated with the video. For each object in the map, the key is the
   * name of the thumbnail image, and the value is an object that contains other information about
   * the thumbnail.
   * The value set may be {@code null}.
   */
  public SubscriptionSnippet setThumbnails(ThumbnailDetails thumbnails) {
    this.thumbnails = thumbnails;
    return this;
  }

  /**
   * The subscription's title.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The subscription's title.
   * The value set may be {@code null}.
   */
  public SubscriptionSnippet setTitle(String title) {
    this.title = title;
    return this;
  }

}
