/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * Details about the content of a YouTube Video.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class VideoContentDetails extends GenericJson {

  /**
   * The value of captions indicates whether the video has captions or not.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String caption;

  /**
   * Specifies the ratings that the video received under various rating schemes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ContentRating contentRating;

  /**
   * The countryRestriction object contains information about the countries where a video is (or is
   * not) viewable.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private AccessPolicy countryRestriction;

  /**
   * The value of definition indicates whether the video is available in high definition or only in
   * standard definition.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String definition;

  /**
   * The value of dimension indicates whether the video is available in 3D or in 2D.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String dimension;

  /**
   * The length of the video. The tag value is an ISO 8601 duration in the format PT#M#S, in which
   * the letters PT indicate that the value specifies a period of time, and the letters M and S
   * refer to length in minutes and seconds, respectively. The # characters preceding the M and S
   * letters are both integers that specify the number of minutes (or seconds) of the video. For
   * example, a value of PT15M51S indicates that the video is 15 minutes and 51 seconds long.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String duration;

  /**
   * The value of is_license_content indicates whether the video is licensed content.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean licensedContent;

  /**
   * The regionRestriction object contains information about the countries where a video is (or is
   * not) viewable. The object will contain either the contentDetails.regionRestriction.allowed
   * property or the contentDetails.regionRestriction.blocked property.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private VideoContentDetailsRegionRestriction regionRestriction;

  /**
   * The value of captions indicates whether the video has captions or not.
   * The value returned may be {@code null}.
   */
  public String getCaption() {
    return caption;
  }

  /**
   * The value of captions indicates whether the video has captions or not.
   * The value set may be {@code null}.
   */
  public VideoContentDetails setCaption(String caption) {
    this.caption = caption;
    return this;
  }

  /**
   * Specifies the ratings that the video received under various rating schemes.
   * The value returned may be {@code null}.
   */
  public ContentRating getContentRating() {
    return contentRating;
  }

  /**
   * Specifies the ratings that the video received under various rating schemes.
   * The value set may be {@code null}.
   */
  public VideoContentDetails setContentRating(ContentRating contentRating) {
    this.contentRating = contentRating;
    return this;
  }

  /**
   * The countryRestriction object contains information about the countries where a video is (or is
   * not) viewable.
   * The value returned may be {@code null}.
   */
  public AccessPolicy getCountryRestriction() {
    return countryRestriction;
  }

  /**
   * The countryRestriction object contains information about the countries where a video is (or is
   * not) viewable.
   * The value set may be {@code null}.
   */
  public VideoContentDetails setCountryRestriction(AccessPolicy countryRestriction) {
    this.countryRestriction = countryRestriction;
    return this;
  }

  /**
   * The value of definition indicates whether the video is available in high definition or only in
   * standard definition.
   * The value returned may be {@code null}.
   */
  public String getDefinition() {
    return definition;
  }

  /**
   * The value of definition indicates whether the video is available in high definition or only in
   * standard definition.
   * The value set may be {@code null}.
   */
  public VideoContentDetails setDefinition(String definition) {
    this.definition = definition;
    return this;
  }

  /**
   * The value of dimension indicates whether the video is available in 3D or in 2D.
   * The value returned may be {@code null}.
   */
  public String getDimension() {
    return dimension;
  }

  /**
   * The value of dimension indicates whether the video is available in 3D or in 2D.
   * The value set may be {@code null}.
   */
  public VideoContentDetails setDimension(String dimension) {
    this.dimension = dimension;
    return this;
  }

  /**
   * The length of the video. The tag value is an ISO 8601 duration in the format PT#M#S, in which
   * the letters PT indicate that the value specifies a period of time, and the letters M and S
   * refer to length in minutes and seconds, respectively. The # characters preceding the M and S
   * letters are both integers that specify the number of minutes (or seconds) of the video. For
   * example, a value of PT15M51S indicates that the video is 15 minutes and 51 seconds long.
   * The value returned may be {@code null}.
   */
  public String getDuration() {
    return duration;
  }

  /**
   * The length of the video. The tag value is an ISO 8601 duration in the format PT#M#S, in which
   * the letters PT indicate that the value specifies a period of time, and the letters M and S
   * refer to length in minutes and seconds, respectively. The # characters preceding the M and S
   * letters are both integers that specify the number of minutes (or seconds) of the video. For
   * example, a value of PT15M51S indicates that the video is 15 minutes and 51 seconds long.
   * The value set may be {@code null}.
   */
  public VideoContentDetails setDuration(String duration) {
    this.duration = duration;
    return this;
  }

  /**
   * The value of is_license_content indicates whether the video is licensed content.
   * The value returned may be {@code null}.
   */
  public Boolean getLicensedContent() {
    return licensedContent;
  }

  /**
   * The value of is_license_content indicates whether the video is licensed content.
   * The value set may be {@code null}.
   */
  public VideoContentDetails setLicensedContent(Boolean licensedContent) {
    this.licensedContent = licensedContent;
    return this;
  }

  /**
   * The regionRestriction object contains information about the countries where a video is (or is
   * not) viewable. The object will contain either the contentDetails.regionRestriction.allowed
   * property or the contentDetails.regionRestriction.blocked property.
   * The value returned may be {@code null}.
   */
  public VideoContentDetailsRegionRestriction getRegionRestriction() {
    return regionRestriction;
  }

  /**
   * The regionRestriction object contains information about the countries where a video is (or is
   * not) viewable. The object will contain either the contentDetails.regionRestriction.allowed
   * property or the contentDetails.regionRestriction.blocked property.
   * The value set may be {@code null}.
   */
  public VideoContentDetails setRegionRestriction(VideoContentDetailsRegionRestriction regionRestriction) {
    this.regionRestriction = regionRestriction;
    return this;
  }

}
