/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.common.primitives.UnsignedLong;

/**
 * Statistics about the video, such as the number of times the video was viewed or liked.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class VideoStatistics extends GenericJson {

  /**
   * The number of comments for the video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong commentCount;

  /**
   * The number of users who have indicated that they disliked the video by giving it a negative
   * rating.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong dislikeCount;

  /**
   * The number of users who currently have the video marked as a favorite video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong favoriteCount;

  /**
   * The number of users who have indicated that they liked the video by giving it a positive
   * rating.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong likeCount;

  /**
   * The number of times the video has been viewed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong viewCount;

  /**
   * The number of comments for the video.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getCommentCount() {
    return commentCount;
  }

  /**
   * The number of comments for the video.
   * The value set may be {@code null}.
   */
  public VideoStatistics setCommentCount(UnsignedLong commentCount) {
    this.commentCount = commentCount;
    return this;
  }

  /**
   * The number of users who have indicated that they disliked the video by giving it a negative
   * rating.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getDislikeCount() {
    return dislikeCount;
  }

  /**
   * The number of users who have indicated that they disliked the video by giving it a negative
   * rating.
   * The value set may be {@code null}.
   */
  public VideoStatistics setDislikeCount(UnsignedLong dislikeCount) {
    this.dislikeCount = dislikeCount;
    return this;
  }

  /**
   * The number of users who currently have the video marked as a favorite video.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getFavoriteCount() {
    return favoriteCount;
  }

  /**
   * The number of users who currently have the video marked as a favorite video.
   * The value set may be {@code null}.
   */
  public VideoStatistics setFavoriteCount(UnsignedLong favoriteCount) {
    this.favoriteCount = favoriteCount;
    return this;
  }

  /**
   * The number of users who have indicated that they liked the video by giving it a positive
   * rating.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getLikeCount() {
    return likeCount;
  }

  /**
   * The number of users who have indicated that they liked the video by giving it a positive
   * rating.
   * The value set may be {@code null}.
   */
  public VideoStatistics setLikeCount(UnsignedLong likeCount) {
    this.likeCount = likeCount;
    return this;
  }

  /**
   * The number of times the video has been viewed.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getViewCount() {
    return viewCount;
  }

  /**
   * The number of times the video has been viewed.
   * The value set may be {@code null}.
   */
  public VideoStatistics setViewCount(UnsignedLong viewCount) {
    this.viewCount = viewCount;
    return this;
  }

}
